==> 2024.11-6866.tar.gz: mastodon-ios/Mastodon/Scene/Search/SearchDetail/SearchResult/SearchResultViewModel.swift <==
//
//  SearchResultViewModel.swift
//  Mastodon
//
//  Created by MainasuK Cirno on 2021-7-14.
//

import Foundation
import Combine
import CoreData
import CoreDataStack
import GameplayKit
import MastodonSDK
import MastodonCore

final class SearchResultViewModel {
    var disposeBag = Set<AnyCancellable>()

    // input
    let context: AppContext
    let authenticationBox: MastodonAuthenticationBox
    let searchScope: SearchScope
    let searchText: String
    @Published var hashtags: [Mastodon.Entity.Tag] = []
    @Published var accounts: [Mastodon.Entity.Account] = []
    var relationships: [Mastodon.Entity.Relationship] = []
    let dataController: StatusDataController

    var cellFrameCache = NSCache<NSNumber, NSValue>()
    var navigationBarFrame = CurrentValueSubject<CGRect, Never>(.zero)

    // output
    var diffableDataSource: UITableViewDiffableDataSource<SearchResultSection, SearchResultItem>!
    @Published var items: [SearchResultItem] = []
    
    private(set) lazy var stateMachine: GKStateMachine = {
        let stateMachine = GKStateMachine(states: [
            State.Initial(viewModel: self),
            State.Loading(viewModel: self),
            State.Fail(viewModel: self),
            State.Idle(viewModel: self),
            State.NoMore(viewModel: self),
        ])
        return stateMachine
    }()
    let didDataSourceUpdate = PassthroughSubject<Void, Never>()

    @MainActor
    init(context: AppContext, authenticationBox: MastodonAuthenticationBox, searchScope: SearchScope = .all, searchText: String) {
        self.context = context
        self.authenticationBox = authenticationBox
        self.searchScope = searchScope
        self.searchText = searchText
        self.accounts = []
        self.relationships = []

        self.dataController = StatusDataController()
    }
}

==> 2025.02-7162.tar.gz: mastodon-ios/Mastodon/Scene/Search/SearchDetail/SearchResult/SearchResultViewModel.swift <==
//
//  SearchResultViewModel.swift
//  Mastodon
//
//  Created by MainasuK Cirno on 2021-7-14.
//

import Foundation
import Combine
import CoreData
import CoreDataStack
import GameplayKit
import MastodonSDK
import MastodonCore

final class SearchResultViewModel {
    var disposeBag = Set<AnyCancellable>()

    // input
    let authenticationBox: MastodonAuthenticationBox
    let searchScope: SearchScope
    let searchText: String
    @Published var hashtags: [Mastodon.Entity.Tag] = []
    @Published var accounts: [Mastodon.Entity.Account] = []
    var relationships: [Mastodon.Entity.Relationship] = []
    let dataController: StatusDataController

    var cellFrameCache = NSCache<NSNumber, NSValue>()
    var navigationBarFrame = CurrentValueSubject<CGRect, Never>(.zero)

    // output
    var diffableDataSource: UITableViewDiffableDataSource<SearchResultSection, SearchResultItem>!
    @Published var items: [SearchResultItem] = []
    
    private(set) lazy var stateMachine: GKStateMachine = {
        let stateMachine = GKStateMachine(states: [
            State.Initial(viewModel: self),
            State.Loading(viewModel: self),
            State.Fail(viewModel: self),
            State.Idle(viewModel: self),
            State.NoMore(viewModel: self),
        ])
        return stateMachine
    }()
    let didDataSourceUpdate = PassthroughSubject<Void, Never>()

    @MainActor
    init(authenticationBox: MastodonAuthenticationBox, searchScope: SearchScope = .all, searchText: String) {
        self.authenticationBox = authenticationBox
        self.searchScope = searchScope
        self.searchText = searchText
        self.accounts = []
        self.relationships = []

        self.dataController = StatusDataController()
    }
}
